/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/mozilla-central-linux-xulrunner/build/dom/indexedDB/nsIIDBDatabase.idl
 */

#ifndef __gen_nsIIDBDatabase_h__
#define __gen_nsIIDBDatabase_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIVariant; /* forward declaration */

class nsIIDBObjectStore; /* forward declaration */

class nsIIDBRequest; /* forward declaration */

class nsIIDBTransaction; /* forward declaration */

class nsIDOMDOMStringList; /* forward declaration */

#include "jsapi.h"

/* starting interface:    nsIIDBDatabase */
#define NS_IIDBDATABASE_IID_STR "c4cfa75f-9f4e-422c-abae-49a8fe3901f8"

#define NS_IIDBDATABASE_IID \
  {0xc4cfa75f, 0x9f4e, 0x422c, \
    { 0xab, 0xae, 0x49, 0xa8, 0xfe, 0x39, 0x01, 0xf8 }}

/**
 * IDBDatabase interface.  See
 * http://dvcs.w3.org/hg/IndexedDB/raw-file/tip/Overview.html#idl-def-IDBDatabase
 * for more information.
 */
class NS_NO_VTABLE NS_SCRIPTABLE nsIIDBDatabase : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIDBDATABASE_IID)

  /* readonly attribute DOMString name; */
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) = 0;

  /* readonly attribute DOMString description; */
  NS_SCRIPTABLE NS_IMETHOD GetDescription(nsAString & aDescription) = 0;

  /* readonly attribute DOMString version; */
  NS_SCRIPTABLE NS_IMETHOD GetVersion(nsAString & aVersion) = 0;

  /* readonly attribute nsIDOMDOMStringList objectStoreNames; */
  NS_SCRIPTABLE NS_IMETHOD GetObjectStoreNames(nsIDOMDOMStringList **aObjectStoreNames) = 0;

  /* nsIIDBObjectStore createObjectStore (in AString name, in AString keyPath, [optional] in boolean autoIncrement); */
  NS_SCRIPTABLE NS_IMETHOD CreateObjectStore(const nsAString & name, const nsAString & keyPath, PRBool autoIncrement, nsIIDBObjectStore **_retval NS_OUTPARAM) = 0;

  /* void removeObjectStore (in AString name); */
  NS_SCRIPTABLE NS_IMETHOD RemoveObjectStore(const nsAString & name) = 0;

  /* [implicit_jscontext] nsIIDBRequest setVersion (in AString version); */
  NS_SCRIPTABLE NS_IMETHOD SetVersion(const nsAString & version, JSContext *cx, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* [optional_argc, implicit_jscontext] nsIIDBTransaction transaction (in nsIVariant storeNames, [optional] in unsigned short mode, [optional] in unsigned long timeout); */
  NS_SCRIPTABLE NS_IMETHOD Transaction(nsIVariant *storeNames, PRUint16 mode, PRUint32 timeout, JSContext *cx, PRUint8 _argc, nsIIDBTransaction **_retval NS_OUTPARAM) = 0;

  /* void close (); */
  NS_SCRIPTABLE NS_IMETHOD Close(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIIDBDatabase, NS_IIDBDATABASE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIDBDATABASE \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName); \
  NS_SCRIPTABLE NS_IMETHOD GetDescription(nsAString & aDescription); \
  NS_SCRIPTABLE NS_IMETHOD GetVersion(nsAString & aVersion); \
  NS_SCRIPTABLE NS_IMETHOD GetObjectStoreNames(nsIDOMDOMStringList **aObjectStoreNames); \
  NS_SCRIPTABLE NS_IMETHOD CreateObjectStore(const nsAString & name, const nsAString & keyPath, PRBool autoIncrement, nsIIDBObjectStore **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD RemoveObjectStore(const nsAString & name); \
  NS_SCRIPTABLE NS_IMETHOD SetVersion(const nsAString & version, JSContext *cx, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD Transaction(nsIVariant *storeNames, PRUint16 mode, PRUint32 timeout, JSContext *cx, PRUint8 _argc, nsIIDBTransaction **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD Close(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIDBDATABASE(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) { return _to GetName(aName); } \
  NS_SCRIPTABLE NS_IMETHOD GetDescription(nsAString & aDescription) { return _to GetDescription(aDescription); } \
  NS_SCRIPTABLE NS_IMETHOD GetVersion(nsAString & aVersion) { return _to GetVersion(aVersion); } \
  NS_SCRIPTABLE NS_IMETHOD GetObjectStoreNames(nsIDOMDOMStringList **aObjectStoreNames) { return _to GetObjectStoreNames(aObjectStoreNames); } \
  NS_SCRIPTABLE NS_IMETHOD CreateObjectStore(const nsAString & name, const nsAString & keyPath, PRBool autoIncrement, nsIIDBObjectStore **_retval NS_OUTPARAM) { return _to CreateObjectStore(name, keyPath, autoIncrement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveObjectStore(const nsAString & name) { return _to RemoveObjectStore(name); } \
  NS_SCRIPTABLE NS_IMETHOD SetVersion(const nsAString & version, JSContext *cx, nsIIDBRequest **_retval NS_OUTPARAM) { return _to SetVersion(version, cx, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Transaction(nsIVariant *storeNames, PRUint16 mode, PRUint32 timeout, JSContext *cx, PRUint8 _argc, nsIIDBTransaction **_retval NS_OUTPARAM) { return _to Transaction(storeNames, mode, timeout, cx, _argc, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Close(void) { return _to Close(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIDBDATABASE(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_SCRIPTABLE NS_IMETHOD GetDescription(nsAString & aDescription) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDescription(aDescription); } \
  NS_SCRIPTABLE NS_IMETHOD GetVersion(nsAString & aVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetVersion(aVersion); } \
  NS_SCRIPTABLE NS_IMETHOD GetObjectStoreNames(nsIDOMDOMStringList **aObjectStoreNames) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetObjectStoreNames(aObjectStoreNames); } \
  NS_SCRIPTABLE NS_IMETHOD CreateObjectStore(const nsAString & name, const nsAString & keyPath, PRBool autoIncrement, nsIIDBObjectStore **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateObjectStore(name, keyPath, autoIncrement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveObjectStore(const nsAString & name) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveObjectStore(name); } \
  NS_SCRIPTABLE NS_IMETHOD SetVersion(const nsAString & version, JSContext *cx, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetVersion(version, cx, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Transaction(nsIVariant *storeNames, PRUint16 mode, PRUint32 timeout, JSContext *cx, PRUint8 _argc, nsIIDBTransaction **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->Transaction(storeNames, mode, timeout, cx, _argc, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Close(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Close(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsIDBDatabase : public nsIIDBDatabase
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIDBDATABASE

  nsIDBDatabase();

private:
  ~nsIDBDatabase();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsIDBDatabase, nsIIDBDatabase)

nsIDBDatabase::nsIDBDatabase()
{
  /* member initializers and constructor code */
}

nsIDBDatabase::~nsIDBDatabase()
{
  /* destructor code */
}

/* readonly attribute DOMString name; */
NS_IMETHODIMP nsIDBDatabase::GetName(nsAString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute DOMString description; */
NS_IMETHODIMP nsIDBDatabase::GetDescription(nsAString & aDescription)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute DOMString version; */
NS_IMETHODIMP nsIDBDatabase::GetVersion(nsAString & aVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIDOMDOMStringList objectStoreNames; */
NS_IMETHODIMP nsIDBDatabase::GetObjectStoreNames(nsIDOMDOMStringList **aObjectStoreNames)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBObjectStore createObjectStore (in AString name, in AString keyPath, [optional] in boolean autoIncrement); */
NS_IMETHODIMP nsIDBDatabase::CreateObjectStore(const nsAString & name, const nsAString & keyPath, PRBool autoIncrement, nsIIDBObjectStore **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeObjectStore (in AString name); */
NS_IMETHODIMP nsIDBDatabase::RemoveObjectStore(const nsAString & name)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [implicit_jscontext] nsIIDBRequest setVersion (in AString version); */
NS_IMETHODIMP nsIDBDatabase::SetVersion(const nsAString & version, JSContext *cx, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [optional_argc, implicit_jscontext] nsIIDBTransaction transaction (in nsIVariant storeNames, [optional] in unsigned short mode, [optional] in unsigned long timeout); */
NS_IMETHODIMP nsIDBDatabase::Transaction(nsIVariant *storeNames, PRUint16 mode, PRUint32 timeout, JSContext *cx, PRUint8 _argc, nsIIDBTransaction **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void close (); */
NS_IMETHODIMP nsIDBDatabase::Close()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIIDBDatabase_h__ */
